==> IMDB-Local-1.0_1.tgz: IMDB-Local/lib/IMDB/Local/ListFiles.pm <==
package IMDB::Local::ListFiles;

use 5.006;
use strict;
use warnings;

=head1 NAME

IMDB::Local::ListFiles - The great new IMDB::Local::Download!

=head1 VERSION

Version 0.01

=cut

our $VERSION = '1.00';

=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use IMDB::Local::Download;

    my $foo = IMDB::Local::ListFiles->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 new

=cut

use Class::MethodMaker
    [ 
      scalar => ['listsDir'],
      scalar => [{-default => 1}, 'movies'],
      scalar => [{-default => 1}, 'directors'],
      scalar => [{-default => 1}, 'actors'],
      scalar => [{-default => 1}, 'actresses'],
      scalar => [{-default => 1}, 'genres'],
      scalar => [{-default => 1}, 'ratings'],
      scalar => [{-default => 1}, 'keywords'],
      scalar => [{-default => 1}, 'plot'],
      
      array => ['listFiles'],
      hash => ['paths'],

      new  => [qw/ -init -hash new /] ,
    ];

sub init
{
    my ($self)=@_;

    if ( ! -d $self->listsDir() ) {
	die $self->listsDir().":does not exist";
    }

    $self->statFiles();
    return($self);
}

sub checkFile
{
    my ($self, $file)=@_;
    
    my $listsDir=$self->{listsDir};
	
    my $filename="$listsDir/$file.list";
    my $filenameGz="$filename.gz";
    my $filenameExists = -f $filename;
    my $filenameSize = -s $filename;
    my $filenameGzExists = -f $filenameGz;
    my $filenameGzSize = -s $filenameGz;
    
    if ( $filenameExists and not $filenameSize ) {
	warn "ignoring zero-length $filename\n";
	#unlink $filename or die "cannot unlink $filename: $!";
	$filenameExists = 0;
    }
    if ( $filenameGzExists and not $filenameGzSize ) {
	warn "ignoring zero-length $filenameGz\n";
	#unlink $filenameGz or die "cannot unlink $filenameGz: $!";
	$filenameGzExists = 0;
    }
    
    $self->listFiles_push($file);

    if ( not $filenameExists and not $filenameGzExists ) {
	#warn "$filenameGz does not exist\n";
	#$self->{missingListFiles}->{$file}=$filenameGz;
	$self->paths_set($file, $filenameGz);
    }
    elsif ( not $filenameExists and $filenameGzExists ) {
	#$self->{imdbListFiles}->{$file}=$filenameGz;
	$self->paths_set($file, $filenameGz);
    }
    elsif ( $filenameExists and not $filenameGzExists ) {
	#$self->{imdbListFiles}->{$file}=$filename;
	$self->paths_set($file, $filename);
    }
    elsif ( $filenameExists and $filenameGzExists ) {
	die "both $filename and $filenameGz exist, remove one of them\n";
    }
    else { die }
}

=head2 new

=cut

sub types
{
    my ($self)=@_;
    my @a=(qw/movies directors actors actresses genres ratings keywords plot/);
    return @a;
}

sub statFiles
{
    my ($self)=@_;

    #delete $self->{missingListFiles};
            
    $self->listFiles_reset();
    $self->paths_reset();

    for my $d ($self->types) {
	if ( $self->$d() ) {
	    $self->checkFile($d);
	}
    }

}

=head1 AUTHOR

jerryv, C<< <jerryv at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-imdb-local at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IMD-Local>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc IMDB::Local::Download


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=IMDB-Local>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/IMDB-Local>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/IMDB-Local>

=item * Search CPAN

L<http://search.cpan.org/dist/IMDB-Local/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2015 jerryv.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of IMDB::Local::Download

==> IMDB-Local-1.0_2.tgz: IMDB-Local/lib/IMDB/Local/ListFiles.pm <==
package IMDB::Local::ListFiles;

use 5.006;
use strict;
use warnings;

=head1 NAME

IMDB::Local::ListFiles - The great new IMDB::Local::Download!

=head1 VERSION

Version 0.01

=cut

our $VERSION = '1.00';

=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use IMDB::Local::Download;

    my $foo = IMDB::Local::ListFiles->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 new

=cut

use Class::MethodMaker
    [ 
      scalar => ['listsDir'],
      scalar => [{-default => 1}, 'movies'],
      scalar => [{-default => 1}, 'directors'],
      scalar => [{-default => 1}, 'actors'],
      scalar => [{-default => 1}, 'actresses'],
      scalar => [{-default => 1}, 'genres'],
      scalar => [{-default => 1}, 'ratings'],
      scalar => [{-default => 1}, 'keywords'],
      scalar => [{-default => 1}, 'plot'],
      
      array => ['listFiles'],
      hash => ['paths'],

      new  => [qw/ -init -hash new /] ,
    ];

sub init
{
    my ($self)=@_;

    if ( ! -d $self->listsDir() ) {
	die $self->listsDir().":does not exist";
    }

    $self->statFiles();
    return($self);
}

sub checkFile
{
    my ($self, $file)=@_;
    
    my $listsDir=$self->{listsDir};
	
    my $filename="$listsDir/$file.list";
    my $filenameGz="$filename.gz";
    my $filenameExists = -f $filename;
    my $filenameSize = -s $filename;
    my $filenameGzExists = -f $filenameGz;
    my $filenameGzSize = -s $filenameGz;
    
    if ( $filenameExists and not $filenameSize ) {
	warn "ignoring zero-length $filename\n";
	#unlink $filename or die "cannot unlink $filename: $!";
	$filenameExists = 0;
    }
    if ( $filenameGzExists and not $filenameGzSize ) {
	warn "ignoring zero-length $filenameGz\n";
	#unlink $filenameGz or die "cannot unlink $filenameGz: $!";
	$filenameGzExists = 0;
    }
    
    $self->listFiles_push($file);

    if ( not $filenameExists and not $filenameGzExists ) {
	#warn "$filenameGz does not exist\n";
	#$self->{missingListFiles}->{$file}=$filenameGz;
	$self->paths_set($file, $filenameGz);
    }
    elsif ( not $filenameExists and $filenameGzExists ) {
	#$self->{imdbListFiles}->{$file}=$filenameGz;
	$self->paths_set($file, $filenameGz);
    }
    elsif ( $filenameExists and not $filenameGzExists ) {
	#$self->{imdbListFiles}->{$file}=$filename;
	$self->paths_set($file, $filename);
    }
    elsif ( $filenameExists and $filenameGzExists ) {
	die "both $filename and $filenameGz exist, remove one of them\n";
    }
    else { die }
}

=head2 new

=cut

sub types
{
    my ($self)=@_;
    my @a=(qw/movies directors actors actresses genres ratings keywords plot/);
    return @a;
}

sub statFiles
{
    my ($self)=@_;

    #delete $self->{missingListFiles};
            
    $self->listFiles_reset();
    $self->paths_reset();

    for my $d ($self->types) {
	if ( $self->$d() ) {
	    $self->checkFile($d);
	}
    }

}

=head1 AUTHOR

jerryv, C<< <jerry.veldhuis at gmail.com> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-imdb-local at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IMD-Local>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc IMDB::Local::Download


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=IMDB-Local>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/IMDB-Local>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/IMDB-Local>

=item * Search CPAN

L<http://search.cpan.org/dist/IMDB-Local/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2015 jerryv.

This program is free software; you can redistribute it and/or modify it
under the terms of the the Artistic License (2.0). You may obtain a
copy of the full license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any use, modification, and distribution of the Standard or Modified
Versions is governed by this Artistic License. By using, modifying or
distributing the Package, you accept this license. Do not use, modify,
or distribute the Package, if you do not accept this license.

If your Modified Version has been derived from a Modified Version made
by someone other than you, you are nevertheless required to ensure that
your Modified Version complies with the requirements of this license.

This license does not grant you the right to use any trademark, service
mark, tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge
patent license to make, have made, use, offer to sell, sell, import and
otherwise transfer the Package with respect to any patent claims
licensable by the Copyright Holder that are necessarily infringed by the
Package. If you institute patent litigation (including a cross-claim or
counterclaim) against any party alleging that the Package constitutes
direct or contributory patent infringement, then this Artistic License
to you shall terminate on the date that such litigation is filed.

Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


=cut

1; # End of IMDB::Local::Download
